@@ -399,12 +399,10 @@ impl_Bonobo_Control_get_property_bag (PortableServer_Servant  servant,
 	if (control->priv->propbag == NULL)
 		return CORBA_OBJECT_NIL;
 
-	corba_propbag = (Bonobo_PropertyBag)
-		bonobo_object_corba_objref (BONOBO_OBJECT (control->priv->propbag));
+	corba_propbag = bonobo_object_corba_objref (
+		BONOBO_OBJECT (control->priv->propbag));
 
-	corba_propbag = CORBA_Object_duplicate (corba_propbag, ev);
-
-	return corba_propbag;
+	return bonobo_object_dup_ref (corba_propbag, ev);
 }
 
 /**
@@ -734,7 +732,7 @@ bonobo_control_destroy (GtkObject *object)
 	CORBA_Object_release (control->priv->control_frame, &ev);
 
 	CORBA_exception_free (&ev);
-	
+
 	/*
 	 * If we have a UIHandler, destroy it.
 	 */
@@ -742,6 +740,12 @@ bonobo_control_destroy (GtkObject *object)
 		bonobo_ui_handler_unset_container (control->priv->uih);
 		bonobo_object_unref (BONOBO_OBJECT (control->priv->uih));
 	}
+}
+
+static void
+bonobo_control_finalize (GtkObject *object)
+{
+	BonoboControl *control = BONOBO_CONTROL (object);
 
 	/*
 	 * Destroy the control's top-level widget.
@@ -759,16 +763,14 @@ bonobo_control_destroy (GtkObject *object)
 	 * which is why we're here now. In the latter case, it's not
 	 * needed because there is no plug.  
 	 */
-
 	if (control->priv->plug) {
-		gtk_object_destroy (GTK_OBJECT (control->priv->plug));
+		gtk_object_unref (GTK_OBJECT (control->priv->plug));
 		control->priv->plug = NULL;
 	}
 
 	g_free (control->priv);
 
-	if (GTK_OBJECT_CLASS (bonobo_control_parent_class)->destroy)
-		(* GTK_OBJECT_CLASS (bonobo_control_parent_class)->destroy) (object);
+	GTK_OBJECT_CLASS (bonobo_control_parent_class)->finalize (object);
 }
 
 /**
@@ -903,15 +905,16 @@ bonobo_control_get_property_bag (BonoboControl *control)
  * @control: A #BonoboControl which is bound to a remote
  * #BonoboControlFrame.
  *
- * Returns: A #BonoboPropertyBagClient bound to the bag of ambient
+ * Returns: A #Bonobo_PropertyBag bound to the bag of ambient
  * properties associated with this #Control's #ControlFrame.
  */
-BonoboPropertyBagClient *
-bonobo_control_get_ambient_properties (BonoboControl *control)
+Bonobo_PropertyBag
+bonobo_control_get_ambient_properties (BonoboControl     *control,
+				       CORBA_Environment *ev)
 {
 	Bonobo_ControlFrame control_frame;
 	Bonobo_PropertyBag pbag;
-	CORBA_Environment ev;
+	CORBA_Environment *real_ev, tmp_ev;
 
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), NULL);
 
@@ -920,18 +923,23 @@ bonobo_control_get_ambient_properties (BonoboControl *control)
 	if (control_frame == CORBA_OBJECT_NIL)
 		return NULL;
 
-	CORBA_exception_init (&ev);
-
-	pbag = Bonobo_ControlFrame_get_ambient_properties (control_frame, &ev);
-
-	if (ev._major != CORBA_NO_EXCEPTION) {
-		bonobo_object_check_env (BONOBO_OBJECT (control), control_frame, &ev);
-		return NULL;
+	if (ev)
+		real_ev = ev;
+	else {
+		CORBA_exception_init (&tmp_ev);
+		real_ev = &tmp_ev;
 	}
 
-	CORBA_exception_free (&ev);
+	pbag = Bonobo_ControlFrame_get_ambient_properties (
+		control_frame, real_ev);
 
-	return bonobo_property_bag_client_new (pbag);
+	if (real_ev->_major != CORBA_NO_EXCEPTION) {
+		if (!ev)
+			CORBA_exception_free (&tmp_ev);
+		pbag = CORBA_OBJECT_NIL;
+	}
+
+	return pbag;
 }
 
 /**
@@ -1026,6 +1034,8 @@ bonobo_control_class_init (BonoboControlClass *klass)
 	gtk_object_class_add_signals (object_class, control_signals, LAST_SIGNAL);
 
 	object_class->destroy = bonobo_control_destroy;
+	object_class->finalize = bonobo_control_finalize;
+
 	init_control_corba_class ();
 }
 
@@ -1070,25 +1080,24 @@ bonobo_control_set_property (BonoboControl       *control,
 			     const char          *first_prop,
 			     ...)
 {
-	BonoboPropertyBagClient *cl;
-	Bonobo_PropertyBag       bag;
-	char                    *err;
+	Bonobo_PropertyBag  bag;
+	char               *err;
+	CORBA_Environment   ev;
+	va_list             args;
+
+	g_return_if_fail (first_prop != NULL);
+	g_return_if_fail (BONOBO_IS_CONTROL (control));
 
-	va_list args;
 	va_start (args, first_prop);
 
-	g_return_if_fail (BONOBO_IS_CONTROL (control));
-	g_return_if_fail (first_prop != NULL);
+	CORBA_exception_init (&ev);
 
-	bonobo_object_ref (BONOBO_OBJECT (control->priv->propbag));
-	bag = (Bonobo_PropertyBag)
-		bonobo_object_corba_objref (BONOBO_OBJECT (control->priv->propbag));
-	cl = bonobo_property_bag_client_new (bag);
+	bag = bonobo_object_corba_objref (BONOBO_OBJECT (control->priv->propbag));
 
-	if ((err = bonobo_property_bag_client_setv (cl, first_prop, args)))
+	if ((err = bonobo_property_bag_client_setv (bag, &ev, first_prop, args)))
 		g_warning ("Error '%s'", err);
 
-	bonobo_object_unref (BONOBO_OBJECT (cl));
+	CORBA_exception_free (&ev);
 
 	va_end (args);
 }
@@ -1098,24 +1107,24 @@ bonobo_control_get_property (BonoboControl       *control,
 			     const char          *first_prop,
 			     ...)
 {
-	BonoboPropertyBagClient *cl;
-	Bonobo_PropertyBag       bag;
-	char                    *err;
+	Bonobo_PropertyBag  bag;
+	char               *err;
+	CORBA_Environment   ev;
+	va_list             args;
+
+	g_return_if_fail (first_prop != NULL);
+	g_return_if_fail (BONOBO_IS_CONTROL (control));
 
-	va_list args;
 	va_start (args, first_prop);
 
-	g_return_if_fail (BONOBO_IS_CONTROL (control));
-	g_return_if_fail (first_prop != NULL);
+	CORBA_exception_init (&ev);
 
-	bag = (Bonobo_PropertyBag)
-		bonobo_object_corba_objref (BONOBO_OBJECT (control->priv->propbag));
-	cl = bonobo_property_bag_client_new (bag);
+	bag = bonobo_object_corba_objref (BONOBO_OBJECT (control->priv->propbag));
 
-	if ((err = bonobo_property_bag_client_getv (cl, first_prop, args)))
+	if ((err = bonobo_property_bag_client_getv (bag, &ev, first_prop, args)))
 		g_warning ("Error '%s'", err);
 
-	bonobo_object_unref (BONOBO_OBJECT (cl));
+	CORBA_exception_free (&ev);
 
 	va_end (args);
 }
