@@ -21,15 +21,15 @@ bonobo_stream_from_servant (PortableServer_Servant servant)
 	return BONOBO_STREAM (bonobo_object_from_servant (servant));
 }
 
-static CORBA_long
+static void
 impl_read (PortableServer_Servant servant,
-	   CORBA_long count,
-	   Bonobo_Stream_iobuf ** buffer,
-	   CORBA_Environment * ev)
+	   CORBA_long             count,
+	   Bonobo_Stream_iobuf  **buffer,
+	   CORBA_Environment     *ev)
 {
 	BonoboStream *stream = bonobo_stream_from_servant (servant);
 
-	return CLASS (stream)->read (stream, count, buffer, ev);
+	CLASS (stream)->read (stream, count, buffer, ev);
 }
 
 static CORBA_long
@@ -175,4 +175,35 @@ bonobo_stream_get_type (void)
 	return type;
 }
 
+/**
+ * bonobo_stream_corba_object_create:
+ * @object: the GtkObject that will wrap the CORBA object
+ *
+ * Creates and activates the CORBA object that is wrapped by the
+ * @object BonoboObject.
+ *
+ * Returns: An activated object reference to the created object
+ * or %CORBA_OBJECT_NIL in case of failure.
+ */
+Bonobo_Stream
+bonobo_stream_corba_object_create (BonoboObject *object)
+{
+	POA_Bonobo_Stream *servant;
+	CORBA_Environment ev;
 
+	servant = (POA_Bonobo_Stream *) g_new0 (BonoboObjectServant, 1);
+	servant->vepv = &bonobo_stream_vepv;
+
+	CORBA_exception_init (&ev);
+
+	POA_Bonobo_Stream__init ((PortableServer_Servant) servant, &ev);
+	if (ev._major != CORBA_NO_EXCEPTION){
+                g_free (servant);
+		CORBA_exception_free (&ev);
+                return CORBA_OBJECT_NIL;
+        }
+
+	CORBA_exception_free (&ev);
+
+	return bonobo_object_activate_servant (object, servant);
+}
