@@ -261,10 +261,6 @@ toolbar_free_data (BonoboUIHandlerToolbarItem *item)
 	item->hint = NULL;
 
 	bonobo_ui_handler_pixmap_free_data (item->pixmap_type, item->pixmap_data);
-
-	if (item->callback_data_destroy_notify != NULL) {
-		(* item->callback_data_destroy_notify) (item->callback_data);
-	}
 }
 
 static void
@@ -1768,6 +1764,11 @@ toolbar_local_remove_item (BonoboUIHandler *uih, const char *path)
 	if (l == NULL)
 		return;
 
+	/*
+	 * FIXME: Menu item code frees the MenuItemLocalInternal here.
+	 * Doesn't this code need something similar?
+	 */
+
 	/*
 	 * Remove the list link.
 	 */
